@@ -18,6 +18,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# DateHandler/_Date_cs.py
+# $Id$
+#
 
 """
 Czech-specific classes for parsing and displaying dates.
@@ -36,9 +39,9 @@ import re
 #
 #-------------------------------------------------------------------------
 from gen.lib import Date
-from DateHandler._DateParser import DateParser
-from DateHandler._DateDisplay import DateDisplay
-from DateHandler._DateHandler import register_datehandler
+from _DateParser import DateParser
+from _DateDisplay import DateDisplay
+from _DateHandler import register_datehandler
 
 #-------------------------------------------------------------------------
 #
@@ -265,5 +268,4 @@ class DateDisplayCZ(DateDisplay):
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(("cs", "CS", "cs_CZ", "cs_CZ.UTF8", "cs_CZ.UTF-8", 
-    "cs_CZ.utf8", "cs_CZ.utf-8"), DateParserCZ, DateDisplayCZ)
+register_datehandler(("cs", "CS", "cs_CZ", "Czech"), DateParserCZ, DateDisplayCZ)
