@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MatchIdOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id$
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -43,8 +43,8 @@ class MatchIdOf(Rule):
     """Rule that checks for a person with a specific GRAMPS ID"""
 
     labels      = [ _('ID:') ]
-    name        = _('People with <Id>')
-    description = _("Matches people with a specified GRAMPS ID")
+    name        = _('Person with <Id>')
+    description = _("Matches person with a specified Gramps ID")
     category    = _('General filters')
 
     def apply(self,db,person):
