@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RegExpIdBase.py 10094 2008-02-22 10:50:06Z acraphae $
+# $Id$
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import re
 
 #-------------------------------------------------------------------------
@@ -47,7 +47,7 @@ class RegExpIdBase(Rule):
 
     labels      = [ _('Regular expression:') ]
     name        = _('Objects with <Id>')
-    description = _("Matches objects whose GRAMPS ID matches "
+    description = _("Matches objects whose Gramps ID matches "
                     "the regular expression")
     category    = _('General filters')
 
@@ -60,4 +60,4 @@ class RegExpIdBase(Rule):
             self.match = re.compile('')
 
     def apply(self, db, obj):
-        return self.match.match(obj.gramps_id) != None
+        return self.match.match(obj.gramps_id) is not None
