@@ -18,40 +18,41 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 7817 2006-12-19 04:47:07Z dallingham $
+# $Id$
 
 """
 Package providing filtering framework for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
-SystemFilters = None
+#SystemFilters = None
 CustomFilters = None
 
-from const import system_filters, custom_filters
+from const import CUSTOM_FILTERS
 from _FilterList import FilterList
 from _GenericFilter import GenericFilter, GenericFilterFactory
 from _ParamFilter import ParamFilter
 
-def reload_system_filters():
-    global SystemFilters
-    SystemFilters = FilterList(system_filters)
-    SystemFilters.load()
+#def reload_system_filters():
+    #global SystemFilters
+    #SystemFilters = FilterList(SYSTEM_FILTERS)
+    #SystemFilters.load()
     
 def reload_custom_filters():
     global CustomFilters
-    CustomFilters = FilterList(custom_filters)
+    CustomFilters = FilterList(CUSTOM_FILTERS)
     CustomFilters.load()
     
-if not SystemFilters:
-    reload_system_filters()
+#if not SystemFilters:
+    #reload_system_filters()
 
 if not CustomFilters:
     reload_custom_filters()
 
-from _FilterComboBox import FilterComboBox
-from _FilterMenu import build_filter_menu, build_filter_model
-from _FilterStore import FilterStore
-from _SearchBar import SearchBar
+try: # the Gramps-Connect server has no DISPLAY
+    from _FilterComboBox import FilterComboBox
+    from _FilterMenu import build_filter_model
+    from _FilterStore import FilterStore
+    from _SearchBar import SearchBar
+except:
+    pass
 from _SearchFilter import SearchFilter, ExactSearchFilter
