@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ImgManip.py 18911 2012-02-17 14:19:44Z nick-h $
+# $Id$
 
 """
 Image manipulation routines.
@@ -105,9 +105,9 @@ def image_dpi(source):
     try:
         import PIL.Image
     except ImportError:
-        import sys
-        print >> sys.stderr, _("WARNING: PIL module not loaded.  "
-                "Image cropping in report files will not be available.")
+        import logging
+        logging.warning(_("WARNING: PIL module not loaded.  "
+                "Image cropping in report files will not be available."))
 
         dpi = None
     else:
