@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TransUtils.py 18597 2011-12-14 19:00:39Z paul-franklin $
+# $Id$
 
 """
 Provide translation assistance
@@ -34,6 +34,7 @@ import gettext
 import sys
 import os
 import locale
+import logging
 
 #-------------------------------------------------------------------------
 #
@@ -58,8 +59,9 @@ else:
     if lang and lang[:2] == 'en':
         pass # No need to display warning, we're in English
     else:
-        print 'Locale dir does not exist at ' + os.path.join(const.PREFIXDIR, "share/locale")
-        print 'Running ./configure --prefix=YourPrefixDir might fix the problem'  
+        logging.warning('Locale dir does not exist at ' + 
+                        os.path.join(const.PREFIXDIR, "share/locale"))
+        logging.warning('Running ./configure --prefix=YourPrefixDir might fix the problem') 
     LOCALEDIR = None
 
 LOCALEDOMAIN = 'gramps'
@@ -77,7 +79,7 @@ else:
             try:
                 lang = locale.getdefaultlocale()[0] + '.UTF-8'
             except TypeError:
-                print 'Unable to determine your Locale, using English'
+                logging.warning('Unable to determine your Locale, using English')
                 lang = 'en.UTF-8'
 
     os.environ["LANG"] = lang
@@ -100,7 +102,7 @@ def setup_gettext():
     try:
         locale.bindtextdomain(LOCALEDOMAIN, LOCALEDIR)
     except ValueError:
-        print 'Failed to bind text domain, gtk.Builder() has no translation'
+        logging.warning('Failed to bind text domain, gtk.Builder() has no translation')
     
     #following installs _ as a python function, we avoid this as TransUtils is
     #used sometimes:
@@ -217,8 +219,8 @@ def setup_windows_gettext():
         return
 
     # No complete/working translation found
-    print "Translation might not be complete/not working for",\
-           locale.getlocale()[0]
+    logging.warning("Translation might not be complete/not working for",\
+           locale.getlocale()[0])
     
 
 def get_localedomain():
