@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: upgrade.py 19355 2012-04-19 05:28:52Z romjerome $
+# $Id$
 
 from __future__ import with_statement
 
@@ -740,7 +740,7 @@ def convert_marker(self, marker_field):
     """Convert a marker into a tag."""
     marker = MarkerType()
     marker.unserialize(marker_field)
-    tag_name = str(marker)
+    tag_name = unicode(marker)
     
     if tag_name != '':
         if tag_name not in self.tags:
