@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: write.py 19550 2012-05-17 09:52:55Z m_d_n $
+# $Id$
 
 """
 Provide the Berkeley DB (DbBsddb) database backend for GRAMPS.
@@ -986,7 +986,8 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
             # to loop through each of the primary object tables.
         
             for cursor_func, class_func in primary_table:
-                print "Rebuilding %s reference map" % class_func.__name__
+                logging.info("Rebuilding %s reference map" %
+                                class_func.__name__)
                 with cursor_func() as cursor:
                     for found_handle, val in cursor:
                         obj = class_func()
