@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: baseobj.py 15645 2010-07-22 02:16:32Z dsblank $
+# $Id$
 
 """
 Base Object class for GRAMPS
@@ -186,3 +186,8 @@ class BaseObject(object):
         :type acquisition: BaseObject
         """
         pass
+
+    @classmethod
+    def create(cls, data):
+        return cls().unserialize(data)
+
