@@ -7,6 +7,7 @@
 # Copyright (C) 2009       Benny Malengier
 # Copyright (C) 2009       Gary Burton
 # Copyright (C) 2010       Peter Landgren
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: textdoc.py 15169 2010-04-16 20:59:10Z bmcage $
+# $Id$
 
 
 
@@ -47,6 +48,13 @@
 import logging
 log = logging.getLogger(".textdoc")
 
+#-------------------------------------------------------------------------
+#
+# URL string pattern
+#
+#-------------------------------------------------------------------------
+URL_PATTERN = r'''(((https?|mailto):)(//([^ /?#"]*))?([^ ?#"]*)(\?([^ #"]*))?(#([^ "]*))?)'''
+
 #-------------------------------------------------------------------------
 #
 # IndexMark types
@@ -54,6 +62,8 @@ log = logging.getLogger(".textdoc")
 #-------------------------------------------------------------------------
 INDEX_TYPE_ALP = 0
 INDEX_TYPE_TOC = 1
+LOCAL_HYPERLINK = 2
+LOCAL_TARGET = 3
 
 #------------------------------------------------------------------------
 #
@@ -160,13 +170,14 @@ class TextDoc(object):
         """
         raise NotImplementedError
 
-    def write_text(self, text, mark=None):
+    def write_text(self, text, mark=None, links=False):
         """
         Writes the text in the current paragraph. Should only be used after a
         start_paragraph and before an end_paragraph.
 
         @param text: text to write.
         @param mark:  IndexMark to use for indexing (if supported)
+        @param links: make URLs in the text clickable (if supported)
         """
         raise NotImplementedError
     
@@ -194,17 +205,8 @@ class TextDoc(object):
         """
         raise NotImplementedError
 
-    def write_endnotes_ref(self, text, style_name):
-        """
-        Writes the note's text and take care of paragraphs, 
-
-        @param text: text to write.
-        @param style_name: style to be used.
-        """
-        raise NotImplementedError
-
     def write_styled_note(self, styledtext, format, style_name,
-                          contains_html=False):
+                          contains_html=False, links=False):
         """
         Convenience function to write a styledtext to the cairo doc. 
         styledtext : assumed a StyledText object to write
@@ -214,13 +216,14 @@ class TextDoc(object):
             If contains_html=True, then the textdoc is free to handle that in 
             some way. Eg, a textdoc could remove all tags, or could make sure
             a link is clickable. 
+        links: bool, make URLs in the text clickable (if supported)
         
         overwrite this method if the backend supports styled notes
         """
         text = str(styledtext)
         self.write_note(text, format, style_name)
     
-    def write_text_citation(self, text, mark=None):
+    def write_text_citation(self, text, mark=None, links=None):
         """
         Method to write text with GRAMPS <super> citation marks.
         """
@@ -235,24 +238,24 @@ class TextDoc(object):
             piecesplit = piece.split("</super>")
             if len(piecesplit) == 2:
                 self.start_superscript()
-                self.write_text(piecesplit[0])
+                self.write_text(piecesplit[0], links=links)
                 self.end_superscript()
                 if not piecesplit[1]:
                     #text ended with ' ... </super>'
                     continue
                 if not markset:
-                    self.write_text(piecesplit[1], mark)
+                    self.write_text(piecesplit[1], mark, links=links)
                     markset = True
                 else:
-                    self.write_text(piecesplit[1])
+                    self.write_text(piecesplit[1], links=links)
             else:
                 if not markset:
-                    self.write_text(piece, mark)
+                    self.write_text(piece, mark, links=links)
                     markset = True
                 else:
-                    self.write_text(piece)
+                    self.write_text(piece, links=links)
 
-    def add_media_object(self, name, align, w_cm, h_cm, alt=''):
+    def add_media_object(self, name, align, w_cm, h_cm, alt='', style_name=None, crop=None):
         """
         Add a photo of the specified width (in centimeters).
 
@@ -262,6 +265,8 @@ class TextDoc(object):
         @param w_cm: width in centimeters
         @param h_cm: height in centimeters
         @param alt: an alternative text to use. Useful for eg html reports
+        @param style_name: style to use for captions
+        @param crop: image cropping parameters
         """
         raise NotImplementedError
     
@@ -293,3 +298,17 @@ class TextDoc(object):
         so that docgen ntypes are not required to have this.
         """
         pass
+
+    def insert_toc(self):
+        """
+        Insert a Table of Contents at this point in the document. This passes 
+        without error so that docgen types are not required to have this.
+        """
+        pass
+
+    def insert_index(self):
+        """
+        Insert an Alphabetical Index at this point in the document. This passes 
+        without error so that docgen types are not required to have this.
+        """
+        pass
