@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _options.py 18886 2012-02-14 23:11:49Z nick-h $
+# $Id$
 
 # Written by Alex Roitman
 
@@ -434,7 +434,7 @@ class OptionListCollection(_options.OptionListCollection):
                     f.write('  <metric value="%d"/>\n' %
                                 option_list.get_paper_metric() )
                 if option_list.get_custom_paper_size():
-                    size = self.get_last_custom_paper_size()
+                    size = option_list.get_custom_paper_size()
                     f.write('  <size value="%f %f"/>\n' % (size[0], size[1]) )
                 if option_list.get_margins():
                     margins = option_list.get_margins()
