@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: groupembeddedlist.py 18696 2012-01-03 21:00:13Z m_d_n $
+# $Id$
 
 #-------------------------------------------------------------------------
 #
@@ -42,6 +42,7 @@ import gobject
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
+import gui.utils
 from embeddedlist import EmbeddedList
 
 #-------------------------------------------------------------------------
@@ -102,7 +103,7 @@ class GroupEmbeddedList(EmbeddedList):
         """
         Handle button press, not double-click, that is done in init_interface
         """
-        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+        if gui.utils.is_right_click(event):
             obj = self.get_selected()
             if obj and obj[1]:
                 self._tmpgroup = obj[0]
