@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editperson.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id$
 
 """
 EditPerson Dialog. Provide the interface to allow the GRAMPS program
@@ -51,7 +51,7 @@ import pango
 #-------------------------------------------------------------------------
 import Utils
 import ThumbNails
-from gui.utils import add_menuitem, open_file_with_default_application
+import gui.utils
 import gen.lib
 from gen.db import DbTxn
 from gui import widgets
@@ -549,12 +549,7 @@ class EditPerson(EditPrimary):
             self.pname.get_primary_surname().set_origintype,
             self.pname.get_primary_surname().get_origintype)
 
-        #remove present surname tab, and put new one based on current prim name
-        msurhbox = self.top.get_object("hboxmultsurnames")
-        msurhbox.remove(self.surntab)
-        self.surntab = SurnameTab(self.dbstate, self.uistate, self.track,
-                       self.obj.get_primary_name())
-        msurhbox.pack_start(self.surntab)
+        self.__renewmultsurnames()
 
         if len(self.pname.get_surname_list()) == 1:
             self.singlesurn_active = True
@@ -597,7 +592,7 @@ class EditPerson(EditPrimary):
                 except Errors.WindowActiveError:
                     pass
 
-        elif event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+        elif gui.utils.is_right_click(event):
             media_list = self.obj.get_media_list()
             if media_list:
                 photo = media_list[0]
@@ -615,9 +610,10 @@ class EditPerson(EditPrimary):
         menu.set_title(_("Media Object"))
         obj = self.db.get_object_from_handle(photo.get_reference_handle())
         if obj:
-            add_menuitem(menu, _("View"), photo, self._popup_view_photo)
-        add_menuitem(menu, _("Edit Object Properties"), photo,
-                           self._popup_change_description)
+            gui.utilsadd_menuitem(menu, _("View"), photo,
+                                  self._popup_view_photo)
+        gui.utils.add_menuitem(menu, _("Edit Object Properties"), photo,
+                               self._popup_change_description)
         menu.popup(None, None, None, event.button, event.time)
 
     def _popup_view_photo(self, obj):
@@ -630,7 +626,7 @@ class EditPerson(EditPrimary):
             object_handle = photo.get_reference_handle()
             ref_obj = self.db.get_object_from_handle(object_handle)
             photo_path = Utils.media_path_full(self.db, ref_obj.get_path())
-            open_file_with_default_application(photo_path)
+            gui.utils.open_file_with_default_application(photo_path)
 
     def _popup_change_description(self, obj):
         """
@@ -901,6 +897,8 @@ class EditPerson(EditPrimary):
         msurhbox.remove(self.surntab)
         self.surntab = SurnameTab(self.dbstate, self.uistate, self.track,
                        self.obj.get_primary_name())
+        self.multsurnfr.set_size_request(-1,
+                                int(config.get('interface.surname-box-height')))
         msurhbox.pack_start(self.surntab)
 
     def load_person_image(self):
