@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: grampsbar.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id$
 
 """
 Module that implements the sidebar and bottombar fuctionality.
@@ -57,7 +57,7 @@ from gui.widgets.grampletpane import (AVAILABLE_GRAMPLETS,
                                       make_requested_gramplet,
                                       GuiGramplet)
 from gui.widgets.undoablebuffer import UndoableBuffer
-from gui.utils import add_menuitem
+import gui.utils
 from QuestionDialog import QuestionDialog
 
 #-------------------------------------------------------------------------
@@ -415,7 +415,7 @@ class GrampsBar(gtk.Notebook):
         """
         Called when a button is pressed in the tabs section of the GrampsBar.
         """
-        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+        if gui.utils.is_right_click(event):
             menu = gtk.Menu()
 
             ag_menu = gtk.MenuItem(_('Add a gramplet'))
