@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: navigationview.py 18585 2011-12-12 18:37:53Z m_d_n $
+# $Id$
 
 """
 Provide the base classes for GRAMPS' DataView classes
@@ -330,6 +330,10 @@ class NavigationView(PageView):
         defperson = self.dbstate.db.get_default_person()
         if defperson:
             self.change_active(defperson.get_handle())
+        else:
+            from QuestionDialog import WarningDialog
+            WarningDialog(_("No Home Person"), 
+                          _("You need to set a 'default person' to go to."))
 
     def jump(self):
         """
