@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id:_PlaceModel.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id$
 
 """
 Place Model.
@@ -156,7 +156,7 @@ class PlaceBaseModel(object):
     def sort_longitude(self, data):
         if not data[3]:
             return u' '
-        value = conv_lat_lon('0', data[3], format='ISO-DMS')
+        value = conv_lat_lon('0', data[3], format='ISO-DMS') if data[3] else u''
         if not value:
              return _("Error in format")
         return value
@@ -164,7 +164,7 @@ class PlaceBaseModel(object):
     def sort_latitude(self, data):
         if not data[4]:
             return u' '
-        value = conv_lat_lon(data[4], '0', format='ISO-DMS')
+        value = conv_lat_lon(data[4], '0', format='ISO-DMS') if data[4] else u''
         if not value:
             return _("Error in format")
         return value 
@@ -288,7 +288,6 @@ class PlaceTreeModel(PlaceBaseModel, TreeBaseModel):
         Unset all elements that can prevent garbage collection
         """
         PlaceBaseModel.destroy(self)
-        self.hmap = None
         self.number_items = None
         TreeBaseModel.destroy(self)
 
@@ -297,7 +296,6 @@ class PlaceTreeModel(PlaceBaseModel, TreeBaseModel):
         PlaceBaseModel
         """
         self.number_items = self.db.get_number_of_places
-        self.hmap = [self.column_header] + [None]*14
 
     def get_tree_levels(self):
         """
