@@ -24,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExportXml.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id$
 
 """
 Contains the interface to allow a database to get written using
@@ -278,7 +278,7 @@ class GrampsXmlWriter(UpdateCallback):
 
         if family_len > 0:
             self.g.write("  <families>\n")
-            for handle in sorted(self.db.get_family_handles()):
+            for handle in sorted(self.db.iter_family_handles()):
                 family = self.db.get_family_from_handle(handle)
                 self.write_family(family,2)
                 self.update()
@@ -286,7 +286,7 @@ class GrampsXmlWriter(UpdateCallback):
 
         if citation_len > 0:
             self.g.write("  <citations>\n")
-            for handle in self.db.get_citation_handles():
+            for handle in sorted(self.db.get_citation_handles()):
                 citation = self.db.get_citation_from_handle(handle)
                 self.write_citation(citation,2)
                 self.update()
@@ -366,6 +366,7 @@ class GrampsXmlWriter(UpdateCallback):
         bm_family_len = len(self.db.family_bookmarks.get())
         bm_event_len = len(self.db.event_bookmarks.get())
         bm_source_len = len(self.db.source_bookmarks.get())
+        bm_citation_len = len(self.db.citation_bookmarks.get())
         bm_place_len = len(self.db.place_bookmarks.get())
         bm_repo_len = len(self.db.repo_bookmarks.get())
         bm_obj_len = len(self.db.media_bookmarks.get())
@@ -373,7 +374,7 @@ class GrampsXmlWriter(UpdateCallback):
 
         bm_len = (bm_person_len + bm_family_len + bm_event_len +
                   bm_source_len + bm_place_len + bm_repo_len +
-                  bm_obj_len + bm_note_len
+                  bm_citation_len + bm_obj_len + bm_note_len
                   )
         
         if bm_len > 0:
@@ -391,6 +392,9 @@ class GrampsXmlWriter(UpdateCallback):
             for handle in self.db.get_source_bookmarks().get():
                 self.g.write('    <bookmark target="source" hlink="_%s"/>\n'
                              % handle )
+            for handle in self.db.get_citation_bookmarks().get():
+                self.g.write('    <bookmark target="citation" hlink="_%s"/>\n'
+                             % handle )
             for handle in self.db.get_place_bookmarks().get():
                 self.g.write('    <bookmark target="place" hlink="_%s"/>\n'
                              % handle )
@@ -522,10 +526,10 @@ class GrampsXmlWriter(UpdateCallback):
         self.write_attribute_list(person.get_attribute_list())
         self.write_url_list(person.get_url_list(),index+1)
 
-        for family_handle in sorted(person.get_parent_family_handle_list()):
+        for family_handle in person.get_parent_family_handle_list():
             self.write_ref("childof",family_handle,index+1)
 
-        for family_handle in sorted(person.get_family_handle_list()):
+        for family_handle in person.get_family_handle_list():
             self.write_ref("parentin",family_handle,index+1)
 
         for person_ref in person.get_person_ref_list():
