@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: MediaPreview.py 18678 2012-01-01 17:57:42Z nick-h $
+# $Id$
 #
 
 from gen.plug import Gramplet
@@ -38,7 +38,7 @@ class MediaPreview(Gramplet):
         Build the GUI interface.
         """
         self.top = gtk.HBox()
-        self.photo = Photo()
+        self.photo = Photo(self.uistate.screen_height() < 1000)
         self.top.pack_start(self.photo, fill=True, expand=False, padding=5)
         self.top.show_all()
         return self.top
