@@ -16,14 +16,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: SessionLogGramplet.py 17151 2011-04-19 15:26:15Z m_d_n $
+# $Id$
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import locale
 import time
 
 from gen.lib import Person, Family
@@ -39,8 +38,6 @@ from Utils import family_name
 #
 #------------------------------------------------------------------------
 class LogGramplet(Gramplet):
-    _t_fmt = locale.nl_langinfo(locale.T_FMT)
-    
     def init(self):
         self.set_tooltip(_("Click name to change active\nDouble-click name to edit"))
         self.set_text(_("Log for this Session") + "\n")
@@ -48,7 +45,7 @@ class LogGramplet(Gramplet):
         self.last_log = None
         
     def timestamp(self):
-        self.append_text(time.strftime(LogGramplet._t_fmt) + " ")
+        self.append_text(time.strftime("%Y-%m-%d %H:%M:%S "))
 
     def db_changed(self):
         self.timestamp()
