@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: bottombar.gpr.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id$
 
 #------------------------------------------------------------------------
 #
@@ -86,9 +86,9 @@ try:
     import pyexiv2
     available = True
 except:
-    import sys
-    print >> sys.stderr, _("WARNING: pyexiv2 module not loaded.  "
-            "Image metadata functionality will not be available.")
+    import logging
+    logging.warning(_("WARNING: pyexiv2 module not loaded.  "
+                      "Image metadata functionality will not be available."))
     available = False
 
 if available:
