@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gramplet.gpr.py 18338 2011-10-16 20:21:22Z paul-franklin $
+# $Id$
 
 #------------------------------------------------------------------------
 #
@@ -162,20 +162,6 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Plugin Manager", 
-         name=_("Plugin Manager"), 
-         description = _("Gramplet showing available third-party plugins (addons)"),
-         status = STABLE,
-         fname="PluginManagerGramplet.py",
-         height=300,
-         expand=True,
-         gramplet = 'PluginManagerGramplet',
-         gramplet_title=_("Plugin Manager"),
-         version="1.0.0",
-         gramps_target_version="3.4",
-         )
-
 register(GRAMPLET, 
          id="Quick View", 
          name=_("Quick View"), 
