@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: NotRelated.py 18915 2012-02-17 16:51:40Z romjerome $
+# $Id$
 
 "Find people who are not related to the selected person"
 
@@ -241,7 +241,7 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
     def applyTagClicked(self, button) :
         progress    = None
         rows        = self.treeSelection.count_selected_rows()
-        tag_name    = self.tagcombo.get_active_text()
+        tag_name    = unicode(self.tagcombo.get_active_text())
 
         # start the db transaction
         with DbTxn("Tag not related", self.db) as transaction:
