@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Verify.py 19450 2012-05-06 09:46:29Z m_d_n $
+# $Id$
 
 """
 A plugin to verify the data against user-adjusted tests.
@@ -136,6 +136,9 @@ def get_date_from_event_type(db,person,event_type,estimate=False):
     for event_ref in person.get_event_ref_list():
         event = find_event(db,event_ref.ref)
         if event:
+            if event_ref.get_role() != gen.lib.EventRoleType.PRIMARY and \
+                event.get_type() == gen.lib.EventType.BURIAL:
+                continue
             if event.get_type() == event_type:
                 date_obj = event.get_date_object()
                 if not estimate and \
