@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: fanchartview.py 16319 2010-12-28 17:04:41Z nick-h $
+# $Id$
 
 ## Based on the paper:
 ##   http://www.cs.utah.edu/~draperg/research/fanchart/draperg_FHT08.pdf
@@ -61,6 +61,7 @@ from gui.views.navigationview import NavigationView
 import Errors
 import Bookmarks
 from gui.editors import EditPerson
+import gui.utils
 
 #-------------------------------------------------------------------------
 #
@@ -539,7 +540,7 @@ class FanChartWidget(gtk.Widget):
         if selected is None: # clicked in open area, or center
             if radius < self.center:
                 # right mouse
-                if event.button == 3 and self.context_popup_callback: 
+                if gui.utils.is_right_click(event):
                     if self.data[0][0][1]:
                         self.context_popup_callback(widget, event, 
                                                     self.data[0][0][1].handle)
@@ -554,7 +555,7 @@ class FanChartWidget(gtk.Widget):
         # Do things based on state, event.state, or button, event.button
         if event.button == 1: # left mouse
             self.change_slice(generation, selected)
-        elif event.button == 3: # right mouse
+        elif gui.utils.is_right_click(event):
             text, person, parents, child = self.data[generation][selected]
             if person and self.context_popup_callback:
                 self.context_popup_callback(widget, event, person.handle)
