@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: pedigreeview.py 18672 2011-12-31 22:04:06Z nick-h $
+# $Id$
 
 #-------------------------------------------------------------------------
 #
@@ -64,6 +64,7 @@ import Bookmarks
 import const
 import constfunc
 from QuestionDialog import RunDatabaseRepair, ErrorDialog
+import gui.utils
 
 #-------------------------------------------------------------------------
 #
@@ -279,6 +280,7 @@ class PersonBoxWidgetCairo(_PersonWidgetBase):
         #self.context.stroke()
 
         # Create box shape and store path
+        self.context.save()
         self.context.move_to(0, 5)
         self.context.curve_to(0, 2, 2, 0, 5, 0)
         self.context.line_to(alloc.width-8, 0)
@@ -324,6 +326,7 @@ class PersonBoxWidgetCairo(_PersonWidgetBase):
             self.context.paint()
 
         # text
+        self.context.restore()
         self.context.move_to(5, 4)
         self.context.set_source_rgb(0, 0, 0)
         self.context.show_layout(self.textlayout)
@@ -1511,7 +1514,7 @@ class PedigreeView(NavigationView):
             self._last_y = event.y
             self._in_move = True
             return True
-        elif event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS:
+        elif gui.utils.is_right_click(event):
             self.cb_on_show_option_menu(widget, event)
             return True
         return False
@@ -1565,7 +1568,7 @@ class PedigreeView(NavigationView):
         or submenu for person for mouse right click.
         And setup plug for button press on person widget.
         """
-        if event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS:
+        if gui.utils.is_right_click(event):
             self.cb_build_full_nav_menu(obj, event,
                                         person_handle, family_handle)
             return True
@@ -1580,7 +1583,7 @@ class PedigreeView(NavigationView):
         on family line or call full submenu for mouse right click.
         And setup plug for button press on family line.
         """
-        if event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS:
+        if gui.utils.is_right_click(event):
             self.cb_build_relation_nav_menu(obj, event, family_handle)
             return True
         elif event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS:
@@ -1597,7 +1600,7 @@ class PedigreeView(NavigationView):
         if event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS:
             self.cb_add_parents(obj, person_handle, family_handle)
             return True
-        elif event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS:
+        elif gui.utils.is_right_click(event):
             self.cb_build_missing_parent_nav_menu(obj, event, person_handle,
                                                   family_handle)
             return True
